ndarray(data)
#############

.. doxygenfunction:: librapid::basic_ndarray::basic_ndarray(const std::vector<V> &values)
.. doxygenfunction:: librapid::basic_ndarray::from_data(V scalar)
.. doxygenfunction:: librapid::basic_ndarray::from_data(const std::vector<V> &data)
